Ext.define('DSS.addon.IlluminantType', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    vendorGrid : null,
    typeGrid : null,
    grafic : null,
    macPanel : null,
    iDefaultWidth : 150,
    iDefaultHeight : 293,
    iSelectedID:null,
    setHeight : function(oHeight) {
        this.macPanel.setHeight(oHeight - 125);
        this.iDefaultHeight = oHeight - 127;
        if (this.vendorGrid != null)
            this.vendorGrid.setHeight(this.iDefaultHeight);
        if (this.typeGrid != null)
            this.typeGrid.setHeight(this.iDefaultHeight);
        this.callParent(arguments);
    },
    initStores : function() {
        if (Ext.data.StoreManager.lookup('illuminateChartValues') == null) {
            Ext.create('Ext.data.Store', {
                storeId : 'illuminateChartValues',
                fields : [ '_id','value','window'],
                proxy : {
                    type : 'memory',
                    reader : {
                        type : 'json',
                        root : 'items'
                    }
                }
            });   
        }
    },
    updateGridStores : function() {
        var me=this;
        var vendorStore = Ext.data.StoreManager.lookup('illuminateVendorStore');
        var typeControlStore = Ext.data.StoreManager.lookup('illuminateTypeControlStore');

        if (this.vendorGrid !== null) {
            this.vendorGrid.getStore().removeAll();
            vendorStore.each(function(record) {
                var oNewRecord = record.copy();
                me.vendorGrid.getStore().add(oNewRecord);
            });          
        }

        if (this.typeGrid !== null) {
            this.typeGrid.getStore().removeAll();
            typeControlStore.each(function(record) {
                var oNewRecord = record.copy();
                me.typeGrid.getStore().add(oNewRecord);
            });          
        }
        
    },
    constructGrid : function() {
        var me = this;

        var vendorStore = Ext.data.StoreManager.lookup('illuminateVendorStore');
        var vendorTempStore = Ext.create('Ext.data.Store', {
            fields : [ '_id', {name:'vendor', sortType: 'asUCText'}, 'passive' ],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                    }
                }
        });
        vendorStore.each(function(record) {
            var oNewRecord = record.copy();
            vendorTempStore.add(oNewRecord);
        });

        this.vendorGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 150,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store : vendorTempStore,
            columns : [ {
                sortable : true,
                hideable : false,
                text : _('Vendor'),
                dataIndex : 'vendor',
                flex : 1, 
                renderer: function (sValue) {
                	return sValue.substr(1);
                }
            } ]
        });
        this.vendorGrid.parent = this;

        this.vendorGrid.on('itemclick', function(grid, record) {
            var selection = me.typeGrid.getSelectionModel().getSelection();
            var typeControlStore = me.typeGrid.getStore();
            me.typeGrid.getStore().clearFilter();
            if (record.get('_id')!=0) {
                typeControlStore.filterBy(function (r){return r.get('manufactureID')==record.get('_id');});
            }
            if (selection.length > 0) {
                var selectionId = selection[0].get('_id');
                if (typeControlStore.find('_id', selectionId) === -1) {
                    me.typeGrid.getSelectionModel().deselectAll();
                }
            }            
            this.parent.macPanel.doLayout();
        });
        


        var typeControlStore = Ext.data.StoreManager.lookup('illuminateTypeControlStore');      
        var typeControlTempStore = Ext.create('Ext.data.Store', {
            fields : [ {name:'name', sortType: 'asUCText'},
                       '_id',
                       'ability',
                       'abilityDetail',
                       'colortemp',
                       'curveValues',
                       'dimmMinimum',
                       'ean',
                       'illuminateCount',
                       'lumen',
                       'manufactureID',
                       'mount',
                       'winkel',
                       {name:'socket', sortType: 'asUCText'},
                       {name:'watt',sortType:'asCommaFloat'}],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });
        typeControlStore.each(function(record) {
            var oNewRecord = record.copy();
            typeControlTempStore.add(oNewRecord);
        });

        this.typeGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 622,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store : typeControlTempStore,
            columns : [ {
                sortable : true,
                hideable : false,
                text : _('Socket'),
                dataIndex : 'socket',
                width: 40
            },
            {
                sortable : true,
                hideable : false,
                text : _('Type'),
                dataIndex : 'name',
                flex : 4
            },{
                sortable : true,
                hideable : false,
                text : _('Power'),
                dataIndex : 'watt',
                renderer: function (value)
                {
                	return value + _('W');
                }
            },{
                sortable : true,
                hideable : false,
                text : _('Colortemperature'),
                dataIndex : 'colortemp',
                renderer: function (value)
                {
                    if(value =='') 
                    	return _('not avaible');
                    else
                    	return value +"K";
                    	
                } 
            },           
            {
                sortable : true,
                hideable : false,
                text : _('dimming capatility'),
                dataIndex : 'ability',
                renderer: function (value)
                {
                    var returnString;
                    switch(value) {
                        case 2: 
                            returnString = '<img src="images/status_ok.png"/>';
                            break;
                        case 1: 
                            returnString = '<img src="images/status_critical.png"/>';
                            break;
                        case 0:
                            returnString = '<img src="images/status_error.png"/>';
                            break;
                        default: 
                            returnString = '<img src="images/status_critical.png"/>';
                            break;
                    }
                    return returnString;
                },
                width: 50
            } ]
        });
        this.typeGrid.parent = this;

        
        this.typeGrid.on('selectionchange', function(model,record) {
            Ext.data.StoreManager.lookup('illuminateChartValues').removeAll();
            if (record.length>0) {
            	this.parent.iSelectedID=record[0].get('_id');
            	if (record[0].get('dimmMinimum')==-1)
            		this.parent.dimmbarPanel.setValue('-');
            	else
            	if (record[0].get('ability')==0)
            		this.parent.dimmbarPanel.setValue(_('not dimmable - select switching mode'));
            	else
            		this.parent.dimmbarPanel.setValue(record[0].get('dimmMinimum') +"% - 100%");
            	if (record[0].get('lumen')=="")
            		this.parent.lumenPanel.setValue(_('not avaible'));
            	else
            		this.parent.lumenPanel.setValue(record[0].get('lumen') + _('lm'));
            	if ("" + record[0].get('winkel')=="0")
            		this.parent.winkelPanel.setValue(_('not avaible'));
            	else
            		this.parent.winkelPanel.setValue(record[0].get('winkel') + "&deg;");
            	if (record[0].get('ean')=="")
            		this.parent.eanPanel.setValue(_('not avaible'));
            	else {
            		/*if (record[0].get('ean').length!=13)
            			this.parent.eanPanel.setFieldLabel(_('EAN'));
            		else
            			this.parent.eanPanel.setFieldLabel(_('article number'));*/
            			
            		this.parent.eanPanel.setValue(record[0].get('ean'));
            	}
            	this.parent.bewertungsPanel.setValue(_(record[0].get('abilityDetail')));
            	
            	var oBaseRecord=Ext.data.StoreManager.lookup('illuminateTypeStore').findRecord('_id',this.parent.iSelectedID,0,false,false,true);  
            	
                var oValues=oBaseRecord.get('curveValues');
                if (oValues.length==0) {
                	dss.raiseEvent('led-wizard.query-'+oBaseRecord.get('manufactureID'),{illuminantID:this.parent.iSelectedID});
                }
                if (oValues!="") {
	                oValues.sort(function (a,b){return a._id-b._id;});
	                for (var iIndex=0;iIndex<oValues.length;iIndex++) {
	                    Ext.data.StoreManager.lookup('illuminateChartValues').add({_id:iIndex,value:oValues[iIndex].value,window:oValues[iIndex].window});
	                }
                }
                this.parent.macPanel.doLayout();
            } else {
                this.parent.iSelectedID = null;
            }
            this.parent.updateChartStore();
        });

    },
    constructor : function(config) {
        var me=this;
        this.initStores();
        this.constructGrid();
        this.macPanel = Ext.create('Ext.panel.Panel', {
            border : '0',
            autoScroll : true,
            height : 200,
            width : 774,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [ this.vendorGrid,this.typeGrid  ]
        });

        var chartStore = Ext.data.StoreManager.lookup('illuminateChartValues');
        var tempChartStore = Ext.create('Ext.data.Store', {
            fields : [ '_id','value','window'],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });   
        chartStore.each(function(record) {
            var oNewRecord = record.copy();
            tempChartStore.add(oNewRecord);
        });        
        this.grafic = Ext.create('Ext.chart.Chart', {
            store : tempChartStore,
            height : 90,
            width: 285,
            animate: true,
            
            series: [ {
                         type: 'line',
                         xField: '_id',
                         yField: 'value',
                         fill: true,
                         markerConfig: {
                             type: 'circle',
                             radius: 4,
                             'fill': '#ffff00'
                         },
                         style: {
                        	 'fill':'#dff6e8',
                        	 stroke:'#99E8BC',
                        	 opacity: 1
                         }
                     },
                     {
                         type: 'line',
                         xField: '_id',
                         yField: 'window',
                         fill: true,
                         markerConfig: {
                             type: 'circle',
                             radius: 4,
                             'fill': '#ffff00'
                         },
                         style: {
                        	 'fill':'#ffff00',
                        	 stroke:'#ffff00',
                        	 opacity: 0.2
                         },
                         showMarkers:false
                     }]
        });
        this.grafic.themeAttrs.colors=['#dff6e8','#ffff00'];
        this.bewertungsPanel=Ext.create('Ext.form.field.Display',{
            height:60,
            labelWidth:80,
            width:324,
            fieldStyle: {'vertical-align':'top', 'height':'57px','padding-top':'0'},
            fieldLabel:_('Bewertung'),
            value:_('choose illuminant first')
        });
        
        this.eanPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            labelWidth:80,
            width:220,
            fieldLabel:_('EAN'),
            value:_('choose illuminant first')
        });
        
        this.winkelPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            labelWidth:80,
            width:180,
            fieldLabel:_('angle'),
            value:_('choose illuminant first')
        });
        
        this.lumenPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            labelWidth:80,
            width:180,
            fieldLabel:_('Lumen'),
            value:_('choose illuminant first')
        });
        
        this.dimmbarPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            labelWidth:80,
            width:220,
            fieldLabel:_('dimmable'),
            value:_('choose illuminant first')
        });
        
        this.bottonLabel=Ext.create('Ext.form.field.Display', {
            border : 0,
            height:10,
            width:375,
            padding:"0 0 0 80",            
            align:'middle',
            value:_('phase angle'),
             style: {
                fontSize: '11px'
            }
        });
                        
        this.verticalLabel=Ext.create('Ext.draw.Component', {
            viewBox: false,
            autoSize: true,
            height: 90,
            width:20,
            padding:"20 0 0 0",
            
            items: [{
                type: 'text',
                text: " " + _('brightness'),
                fill: '#005138',
                font: '12px tahoma,arial,verdana,sans-serif',
                rotate: {
                    degrees: 270
                }
            }]
        });
        
        this.graficSubContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 90,
            width : 375,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [this.verticalLabel,this.grafic],
            scroll : 'horizontal'
        });
        
        this.bottomLeftContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 375,
            layout : {
                type : 'vbox',
                flex:0
            },
            align:'middle',
            padding: "10 40 0 20",
            items : [this.graficSubContainer,this.bottonLabel]
        });
        
        this.bottomRightSubContainer1=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 30,
            width : 375,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [this.eanPanel,this.winkelPanel],
            scroll : 'horizontal'
        });
        this.bottomRightSubContainer2=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 30,
            width : 375,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [this.dimmbarPanel, this.lumenPanel],
            scroll : 'horizontal'
        });      

        
        this.bottomRightContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 375,
            layout : {
                type : 'vbox',
                flex:0
            },
            items : [this.bottomRightSubContainer1,this.bottomRightSubContainer2, this.bewertungsPanel],
            scroll : 'horizontal'
        });        
        
        this.bottomContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 774,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [ this.bottomLeftContainer,this.bottomRightContainer ],
            scroll : 'horizontal'
        });
        
        
        Ext.apply(this, {
            layout : {
                type : 'vbox'
            },           
            items : [ this.macPanel, this.bottomContainer ]
        });
        
        Ext.data.StoreManager.lookup('illuminateTypeStore').on('datachanged', function (store, records) {
        	me.updateGridStores();
        	var oBaseRecord=Ext.data.StoreManager.lookup('illuminateTypeStore').findRecord('_id',me.iSelectedID,0,false,false,true);  
        	if (oBaseRecord!=null) {
	            var oValues=oBaseRecord.get('curveValues');
	            if (oValues!="") {
	                oValues.sort(function (a,b){return a._id-b._id;});
	                for (var iIndex=0;iIndex<oValues.length;iIndex++) {
	                    Ext.data.StoreManager.lookup('illuminateChartValues').add({_id:iIndex,value:oValues[iIndex].value,window:oValues[iIndex].window});
	                }
	            }	        	
	        	me.updateChartStore();
        	}
        });              
        this.callParent(arguments);
    },
    updateChartStore : function () {
        var me = this;
        var chartStore = Ext.data.StoreManager.lookup('illuminateChartValues');
        if (this.grafic !== null) {
            this.grafic.getStore().removeAll();
            chartStore.each(function(record) {
                var oNewRecord = record.copy();
                me.grafic.getStore().add(oNewRecord);
            });          
        }
        this.parent.myGrid.editorWindow.editControls.aaa.updateChartStore();
    },
    reset : function() {
        this.setValue(null);
    },
    setValue : function(value) {
    	this.updateGridStores();
        var typeControlStore = this.typeGrid.getStore();
        var vendorStore = this.vendorGrid.getStore();
    	this.iSelectedID=value;
        if (value==null) {
        	this.vendorGrid.getSelectionModel().deselectAll();
        	this.typeGrid.getSelectionModel().deselectAll();
        }
        var oRecord=typeControlStore.findRecord('_id',value,0,false,false,true);
		if (oRecord!=null) {
			var manuID=oRecord.get('manufactureID');
			var oVendorIndex=vendorStore.find('_id',manuID,0,false,false,true);
			if (oVendorIndex!=-1) {
				this.vendorGrid.getSelectionModel().select(oVendorIndex);
				typeControlStore.filter('manufactureID',manuID);
				var iRecordIndex=typeControlStore.find('_id',value,0,false,false,true);
				this.typeGrid.getSelectionModel().select(iRecordIndex);
			}
		}
    },
    isValid : function() {
        return true;
    },
    getValue : function() {
        return this.iSelectedID;
    }
});
